@@ -21,6 +21,7 @@
 #ifndef S3FS_COMMON_H_
 #define S3FS_COMMON_H_
 
+#include <atomic>
 #include <string>
 #include <sys/types.h>
 
@@ -42,10 +43,21 @@ extern std::string    program_name;
 extern std::string    service_path;
 extern std::string    s3host;
 extern std::string    mount_prefix;
-extern std::string    endpoint;
+extern std::string    region;
 extern std::string    cipher_suites;
 extern std::string    instance_name;
 
+extern std::atomic<long long unsigned> num_requests_head_object;
+extern std::atomic<long long unsigned> num_requests_put_object;
+extern std::atomic<long long unsigned> num_requests_get_object;
+extern std::atomic<long long unsigned> num_requests_delete_object;
+extern std::atomic<long long unsigned> num_requests_list_bucket;
+extern std::atomic<long long unsigned> num_requests_mpu_initiate;
+extern std::atomic<long long unsigned> num_requests_mpu_complete;
+extern std::atomic<long long unsigned> num_requests_mpu_abort;
+extern std::atomic<long long unsigned> num_requests_mpu_upload_part;
+extern std::atomic<long long unsigned> num_requests_mpu_copy_part;
+
 //-------------------------------------------------------------------
 // For weak attribute
 //-------------------------------------------------------------------
@@ -54,7 +66,7 @@ extern std::string    instance_name;
 //-------------------------------------------------------------------
 // For clang -Wthread-safety
 //-------------------------------------------------------------------
-#if defined(__clang__)
+#ifdef __clang__
 #define THREAD_ANNOTATION_ATTRIBUTE(x)   __attribute__((x))
 #else
 #define THREAD_ANNOTATION_ATTRIBUTE(x)   // no-op
@@ -72,6 +84,12 @@ extern std::string    instance_name;
 #define RETURN_CAPABILITY(...) \
     THREAD_ANNOTATION_ATTRIBUTE(lock_returned(__VA_ARGS__))
 
+#define ACQUIRED_BEFORE(...) \
+    THREAD_ANNOTATION_ATTRIBUTE(acquired_before(__VA_ARGS__))
+
+#define ACQUIRED_AFTER(...) \
+    THREAD_ANNOTATION_ATTRIBUTE(acquired_after(__VA_ARGS__))
+
 #define NO_THREAD_SAFETY_ANALYSIS \
     THREAD_ANNOTATION_ATTRIBUTE(no_thread_safety_analysis)
 
